# nCoV


Get instant information about 2019-nCoV 获取并记录新冠病毒实时数据


`nCoV` 是一个可以在命令行查询并记录实时新型冠状病毒疫情信息的爬虫应用。
可以选择查看全国总览，各省各市详细信息或全部信息并且可以选择是否以表格文件存储数据



### 使用方式 Usage

```
Usage: nCoV [OPTIONS]

Options:
  -o      Output the overall data of China
  -d      Output detailed data of all provinces and some cities
  -a      Output all data. overall --> detailed (Default)
  --help  Show this message and exit.
```


### 安装 Install

```
$ pip install nCoV
```


### License

[MIT](https://github.com/EthanGeekFan/nCoV/blob/master/LICENSE)
